{#

Add DOI data to the additional_info section

#}

{% ckan_extends %}

{% block package_additional_info %}
    {% if pkg.doi_id %}
        {% snippet "snippets/package_citation.html", pkg_dict=pkg %}
    {% endif %}
    {{ super() }}
{% endblock %}