{#
Renders a citation for a package
#}

{% block citation %}
    <section class="additional-info">

      <h3>{{ _('Cite this as') }}</h3>

        <div class="citation">
            {% set site_title = h.get_site_title() %}
            <p>
                {{ pkg_dict['author'] }} ({{ h.package_get_year(pkg_dict) }}). Dataset: {{ pkg_dict['title'] }}.
                {% if site_title %}
                    {{ site_title }}.
                {% endif %}
            {% block citation_link %}
                <a href="http://dx.doi.org/{{ pkg_dict['doi_id'] }}" target="_blank">http://dx.doi.org/{{ pkg_dict['doi_id'] }}</a></p>
            {% endblock %}
            </p>

        {% block citation_status %}
            <p>Retrieved: {{ h.render_datetime(h.now(), date_format='%H:%M, %d %b %Y') }} (GMT)</p>
        {% endblock %}
        </div>
    </section>

{% endblock %}