{% ckan_extends %}

{% block content_action %}
  {% if not pkg.doi_id %}
    {% if c.userobj.sysadmin %}
      <form id="dataset-doi-admin" method="post" action="{% url_for controller='ckanext.ands.controller:DatasetDoiController', action='dataset_doi_admin', id=pkg.name %}" style="display:inline">
        <button class="btn btn-primary" type="submit" name="Approve DOI">
          <i class="icon-thumbs-up"></i>Approve DOI</button>
      </form>
    {% endif %}
    {% link_for _('Request DOI'), controller='ckanext.ands.controller:DatasetDoiController', action='dataset_doi', id=pkg.name, class_='btn', icon='book' %}
  {% endif %}
  {% if h.check_access('package_update', {'id':pkg.id }) %}
    {% link_for _('Manage'), controller='package', action='edit', id=pkg.name, class_='btn', icon='wrench' %}
  {% endif %}

{% endblock %}